@@ -134,6 +134,7 @@ leiden.matrix <- function(object,
     numpy <- import("numpy", delay_load = TRUE)
     leidenalg <- import("leidenalg", delay_load = TRUE)
     ig <- import("igraph", delay_load = TRUE)
+    pd <- import("pandas", delay_load = TRUE)
 
     #convert matrix input (corrects for sparse matrix input)
     if(is.matrix(object) || is(object, "dgCMatrix")){
@@ -411,9 +412,10 @@ leiden.igraph <- function(object,
 
 
 # global reference to python modules (will be initialized in .onLoad)
-leidenalg <- NULL
-ig <- NULL
-numpy <- NULL
+leidenalg <<- NULL
+ig <<- NULL
+numpy <<- NULL
+pd <<- NULL
 
 #' @importFrom utils install.packages capture.output
 
@@ -445,7 +447,8 @@ numpy <- NULL
                     }
                     suppressWarnings(suppressMessages(reticulate::use_condaenv("r-reticulate")))
                     if(.Platform$OS.type == "windows"){
-                        install.packages("devtools",  quiet = TRUE)
+
+                                             install.packages("devtools",  quiet = TRUE)
                         devtools::install_github("rstudio/reticulate", ref = "86ebb56",  quiet = TRUE)
                         if(!reticulate::py_module_available("numpy")) suppressWarnings(suppressMessages(reticulate::conda_install(envname = "r-reticulate", packages = "numpy")))
                         if(!reticulate::py_module_available("pandas")) suppressWarnings(suppressMessages(reticulate::conda_install(envname = "r-reticulate", packages = "pandas")))
@@ -506,15 +509,19 @@ numpy <- NULL
     }, error = function(e){
         packageStartupMessage("Unable to install python modules igraph and leidenalg")
         packageStartupMessage("run in terminal:")
-        packageStartupMessage("conda install -c conda-forge vtraag python-igraph")
+        packageStartupMessage("conda install -n r-reticulate -c conda-forge vtraag python-igraph pandas umap learn")
     },
     finally = packageStartupMessage("python modules igraph and leidenalg installed"))
     if (suppressWarnings(suppressMessages(requireNamespace("reticulate")))) {
+        modules <- reticulate::py_module_available("pandas")
+        if (modules) {
+            ## assignment in parent environment!
+            pd <- reticulate::import("pandas", delay_load = TRUE)
+        }
         modules <- reticulate::py_module_available("leidenalg") && reticulate::py_module_available("igraph")
         if (modules) {
             ## assignment in parent environment!
             numpy <- reticulate::import("numpy", delay_load = TRUE)
-            pd <- reticulate::import("pandas", delay_load = TRUE)
             leidenalg <- reticulate::import("leidenalg", delay_load = TRUE)
             ig <- reticulate::import("igraph", delay_load = TRUE)
         }
